==> ejc-middlemeasurement-impl-3.0.0-20220428.022448-70-sources.jar: com/ejianc/business/middlemeasurement/controller/api/EngineermeasurementApiController.java <==
package com.ejianc.business.middlemeasurement.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.middlemeasurement.bean.EngineermeasurementEntity;
import com.ejianc.business.middlemeasurement.service.IEngineermeasurementService;
import com.ejianc.business.middlemeasurement.vo.EngineermeasurementVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import java.io.Serializable;
import java.util.*;

/**
 * 工程计量台账
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("api/engineermeasurement")
public class EngineermeasurementApiController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IEngineermeasurementService service;

    /**
     * @Description 根据合同id查询详情
     * @param
     * @Return void
     */
    @RequestMapping(value = "/queryByContractId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<EngineermeasurementVO> queryByContractId(@RequestParam(value = "contractId") Long contractId) {
        QueryWrapper<EngineermeasurementEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("contract_id", contractId);
        queryWrapper.in("bill_state", 1, 3);
        queryWrapper.eq("dr", 0);
        queryWrapper.orderByDesc("create_time");
        queryWrapper.last("limit 1");
        List<EngineermeasurementEntity> list = service.list(queryWrapper);
        EngineermeasurementVO result = new EngineermeasurementVO();
        if(list!=null&&list.size()>0){
            result = BeanMapper.map(list.get(0), EngineermeasurementVO.class);
        }
        return CommonResponse.success("查询数据成功！",result);
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/controller/api/EngineermeasurementApiController.java <==
package com.ejianc.business.middlemeasurement.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.middlemeasurement.bean.EngineermeasurementEntity;
import com.ejianc.business.middlemeasurement.bean.SubcontractingvolumeEntity;
import com.ejianc.business.middlemeasurement.service.IEngineermeasurementService;
import com.ejianc.business.middlemeasurement.vo.EngineermeasurementVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import java.io.Serializable;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 工程计量台账
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("api/engineermeasurement")
public class EngineermeasurementApiController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IEngineermeasurementService service;

    /**
     * @Description 根据合同id查询详情
     * @param
     * @Return void
     */
    @RequestMapping(value = "/queryByContractId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<EngineermeasurementVO> queryByContractId(@RequestParam(value = "contractId") Long contractId) {
        QueryWrapper<EngineermeasurementEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("contract_id", contractId);
        queryWrapper.in("bill_state", 1, 3);
        queryWrapper.eq("dr", 0);
        queryWrapper.orderByDesc("create_time");
        queryWrapper.last("limit 1");
        List<EngineermeasurementEntity> list = service.list(queryWrapper);
        EngineermeasurementVO result = new EngineermeasurementVO();
        if(list!=null&&list.size()>0){
            result = BeanMapper.map(list.get(0), EngineermeasurementVO.class);
        }
        return CommonResponse.success("查询数据成功！",result);
    }

    /**
     * @Description 根据合同id和时间查询 累计合同约定应收款金额、累计收款金额 字段
     * @param
     * @Return void
     */
    @RequestMapping(value = "/selectByContractIdTime", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<EngineermeasurementVO> selectByContractIdTime(@RequestParam(value = "contractId") Long contractId,@RequestParam String reportTime){
        QueryWrapper<EngineermeasurementEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("contract_id", contractId);
        queryWrapper.in("bill_state", 1, 3);
        queryWrapper.eq("dr", 0);
//        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
//        String month = sdf.format(reportTime);
        //当月
        String start = reportTime.substring(0, 7) + "-01";
        //当月最后一天
        Calendar cal = Calendar.getInstance();
        cal.set(Calendar.YEAR, Integer.parseInt(reportTime.substring(0, 4)));
        cal.set(Calendar.MONTH, Integer.parseInt(reportTime.substring(5, 7)) - 1);
        cal.set(Calendar.DAY_OF_MONTH, cal.getActualMaximum(Calendar.DAY_OF_MONTH));
        SimpleDateFormat sdf1 = new SimpleDateFormat("yyyy-MM-dd");
        String end = sdf1.format(cal.getTime());
        queryWrapper.le("reporting_time", end);
        queryWrapper.ge("reporting_time", start);
        EngineermeasurementEntity engineermeasurementEntity = service.getOne(queryWrapper);
        EngineermeasurementVO result = new EngineermeasurementVO();
        if(engineermeasurementEntity!=null){
            result = BeanMapper.map(engineermeasurementEntity, EngineermeasurementVO.class);
        }
        return CommonResponse.success("查询数据成功！",result);
    }
}
